@@ -16,10 +16,9 @@
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 import mobius
+import mobius.core.io
 import pymobius
-from gi.repository import GObject
 from gi.repository import Gtk
-from gi.repository import Pango
 
 from metadata import *
 
@@ -30,7 +29,7 @@ SKYPE_DATATYPE = {0: 'number', 3: 'string', 4: 'raw'}
 
 
 # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-# @brief voicemail object
+# @brief Voicemail object
 # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 class Voicemail(object):
 
@@ -48,7 +47,7 @@ class Voicemail(object):
 
 
 # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-# @brief user object
+# @brief User object
 # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 class User(object):
 
@@ -164,16 +163,15 @@ class SkypeAgent(object):
 
 
 # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-# @brief user list widget
+# @brief User list widget
 # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-class UserListWidget(Gtk.VBox):
+class UserListWidget(object):
 
     # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
     # @brief Initialize widget
     # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
     def __init__(self):
         self.__mediator = pymobius.mediator.copy()
-        self.__factory = self.__mediator.call('ui.new-factory')
         self.__details = {}
         self.__details_report_name = None
 
@@ -182,7 +180,7 @@ class UserListWidget(Gtk.VBox):
         self.__hpaned.set_border_width(5)
         self.__widget = self.__hpaned
 
-        position = mobius.core.get_config('skype-agent.userlist-hpaned-position')
+        position = mobius.framework.get_config('skype-agent.userlist-hpaned-position')
         if position:
             self.__hpaned.set_position(position)
 
@@ -192,7 +190,7 @@ class UserListWidget(Gtk.VBox):
         self.__vpaned.show()
         self.__hpaned.pack1(self.__vpaned, True, True)
 
-        position = mobius.core.get_config('skype-agent.userlist-vpaned-position')
+        position = mobius.framework.get_config('skype-agent.userlist-vpaned-position')
         if position:
             self.__vpaned.set_position(position)
 
@@ -212,20 +210,18 @@ class UserListWidget(Gtk.VBox):
         column = self.__user_listview.add_column('user', column_type='object')
         column.is_visible = False
 
-        self.__user_listview.set_report_app('%s v%s' % (EXTENSION_NAME, EXTENSION_VERSION))
-        self.__user_listview.get_ui_widget().set_border_width(5)
+        self.__user_listview.set_report_app(f'{EXTENSION_NAME} v{EXTENSION_VERSION}')
         self.__user_listview.show()
         self.__vpaned.pack1(self.__user_listview.get_ui_widget(), True, True)
 
         # user image
-        self.__image = Gtk.Image()
-        self.__image.set_from_icon_name('image-missing', Gtk.IconSize.BUTTON)
-        self.__image.show()
-        self.__vpaned.pack2(self.__image, False, True)
+        self.__image = mobius.core.ui.new_icon_by_name('image-missing', mobius.core.ui.icon.size_large)
+        self.__image.set_visible(True)
+        self.__vpaned.pack2(self.__image.get_ui_widget(), False, True)
 
         # user details
         self.__details_listview = self.__mediator.call('ui.new-widget', 'attribute-list')
-        self.__details_listview.set_report_app('%s v%s' % (EXTENSION_NAME, EXTENSION_VERSION))
+        self.__details_listview.set_report_app(f'{EXTENSION_NAME} v{EXTENSION_VERSION}')
         self.__details_listview.show()
         self.__hpaned.pack2(self.__details_listview.get_ui_widget(), True, True)
 
@@ -270,7 +266,7 @@ class UserListWidget(Gtk.VBox):
     def clear(self):
         self.__user_listview.clear()
         self.__details_listview.clear_values()
-        self.__image.set_from_icon_name('image-missing', Gtk.IconSize.DIALOG)
+        self.__image.set_icon_by_name('image-missing', mobius.core.ui.icon.size_large)
 
     # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
     # @brief set widget sensitive status
@@ -289,9 +285,9 @@ class UserListWidget(Gtk.VBox):
     # @brief destroy widget
     # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
     def destroy(self):
-        transaction = mobius.core.new_config_transaction()
-        mobius.core.set_config('skype-agent.userlist-vpaned-position', self.__vpaned.get_position())
-        mobius.core.set_config('skype-agent.userlist-hpaned-position', self.__hpaned.get_position())
+        transaction = mobius.framework.new_config_transaction()
+        mobius.framework.set_config('skype-agent.userlist-vpaned-position', self.__vpaned.get_position())
+        mobius.framework.set_config('skype-agent.userlist-hpaned-position', self.__hpaned.get_position())
         transaction.commit()
 
     # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
@@ -364,13 +360,11 @@ class UserListWidget(Gtk.VBox):
             # user avatar image
             if account.avatar_image:
                 try:
-                    image_buffer = self.__factory.new_image_buffer_from_data(account.avatar_image, 64)
-                    icon = image_buffer.get_ui_widget()
-                    self.__image.set_from_pixbuf(icon)
+                    self.__image.set_icon_from_data(account.avatar_image, mobius.core.ui.icon.size_large)
                 except Exception as e:
-                    self.__image.set_from_icon_name('image-missing', Gtk.IconSize.DIALOG)
+                    self.__image.set_icon_by_name('image-missing', mobius.core.ui.icon.size_large)
             else:
-                self.__image.set_from_icon_name('image-missing', Gtk.IconSize.DIALOG)
+                self.__image.set_icon_by_name('image-missing', mobius.core.ui.icon.size_large)
 
             # report name
             if self.__details_report_name:
@@ -387,26 +381,22 @@ class UserListWidget(Gtk.VBox):
 VIEW_CONTACTS, VIEW_VOICEMAILS, VIEW_TIMELINE, VIEW_RECORDS = range(4)
 
 
-class Widget(Gtk.VBox):
+class Widget(object):
 
     # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
     # @brief Initialize widget
     # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
     def __init__(self):
-        GObject.GObject.__init__(self)
+        self.__widget = mobius.core.ui.box(mobius.core.ui.box.orientation_vertical)
+        self.__widget.set_border_width(10)
+        self.__widget.set_spacing(5)
+        self.__widget.set_visible(True)
         self.__mediator = pymobius.mediator.copy()
-        factory = self.__mediator.call('ui.new-factory')
-
-        self.set_border_width(10)
-        self.set_spacing(5)
-        self.show()
-
-        self.accel_group = Gtk.AccelGroup()
 
         # menubar
         menubar = Gtk.MenuBar()
         menubar.show()
-        self.pack_start(menubar, False, False, 0)
+        self.__widget.add_child(menubar, mobius.core.ui.box.fill_none)
 
         item = Gtk.MenuItem.new_with_mnemonic('_File')
         item.show()
@@ -474,7 +464,7 @@ class Widget(Gtk.VBox):
         toolbar = Gtk.Toolbar()
         toolbar.set_style(Gtk.ToolbarStyle.ICONS)
         toolbar.show()
-        self.pack_start(toolbar, False, False, 0)
+        self.__widget.add_child(toolbar, mobius.core.ui.box.fill_none)
 
         toolitem = Gtk.ToolButton.new()
         toolitem.set_icon_name('document-open')
@@ -485,10 +475,10 @@ class Widget(Gtk.VBox):
 
         self.__report_toolitem = Gtk.ToolButton.new()
 
-        image_buffer = factory.new_image_buffer_by_id('report.run')
-        image = Gtk.Image.new_from_pixbuf(image_buffer.get_ui_widget())
+        image = mobius.core.ui.new_icon_by_name('report-run', mobius.core.ui.icon.size_toolbar)
         image.show()
-        self.__report_toolitem.set_icon_widget(image)
+
+        self.__report_toolitem.set_icon_widget(image.get_ui_widget())
         self.__report_toolitem.set_sensitive(False)
         self.__report_toolitem.connect("clicked", self.on_generate_report)
         self.__report_toolitem.show()
@@ -511,10 +501,9 @@ class Widget(Gtk.VBox):
         self.__view_toolitems[VIEW_CONTACTS] = toolitem
 
         path = pymobius.mediator.call('extension.get-resource-path', EXTENSION_ID, 'view-contacts.png')
-        pixbuf = self.__mediator.call('ui.new-icon-from-file', path, 32, 32)
-        image = Gtk.Image.new_from_pixbuf(pixbuf)
+        image = mobius.core.ui.new_icon_by_path(path, mobius.core.ui.icon.size_dnd)
         image.show()
-        toolitem.set_icon_widget(image)
+        toolitem.set_icon_widget(image.get_ui_widget())
 
         toolitem = Gtk.RadioToolButton(group=toolgroup)
         toolitem.set_sensitive(False)
@@ -525,10 +514,9 @@ class Widget(Gtk.VBox):
         self.__view_toolitems[VIEW_VOICEMAILS] = toolitem
 
         path = pymobius.mediator.call('extension.get-resource-path', EXTENSION_ID, 'view-voicemails.png')
-        pixbuf = self.__mediator.call('ui.new-icon-from-file', path, 32, 32)
-        image = Gtk.Image.new_from_pixbuf(pixbuf)
+        image = mobius.core.ui.new_icon_by_path(path, mobius.core.ui.icon.size_dnd)
         image.show()
-        toolitem.set_icon_widget(image)
+        toolitem.set_icon_widget(image.get_ui_widget())
 
         toolitem = Gtk.SeparatorToolItem()
         toolitem.set_sensitive(False)
@@ -544,10 +532,9 @@ class Widget(Gtk.VBox):
         self.__view_toolitems[VIEW_TIMELINE] = toolitem
 
         path = pymobius.mediator.call('extension.get-resource-path', EXTENSION_ID, 'view-timeline.png')
-        pixbuf = self.__mediator.call('ui.new-icon-from-file', path, 32, 32)
-        image = Gtk.Image.new_from_pixbuf(pixbuf)
+        image = mobius.core.ui.new_icon_by_path(path, mobius.core.ui.icon.size_dnd)
         image.show()
-        toolitem.set_icon_widget(image)
+        toolitem.set_icon_widget(image.get_ui_widget())
 
         toolitem = Gtk.RadioToolButton(group=toolgroup)
         toolitem.set_sensitive(False)
@@ -558,26 +545,26 @@ class Widget(Gtk.VBox):
         self.__view_toolitems[VIEW_RECORDS] = toolitem
 
         path = pymobius.mediator.call('extension.get-resource-path', EXTENSION_ID, 'view-records.png')
-        pixbuf = self.__mediator.call('ui.new-icon-from-file', path, 32, 32)
-        image = Gtk.Image.new_from_pixbuf(pixbuf)
+        image = mobius.core.ui.new_icon_by_path(path, mobius.core.ui.icon.size_dnd)
         image.show()
-        toolitem.set_icon_widget(image)
+        toolitem.set_icon_widget(image.get_ui_widget())
 
         # notebook
         self.__notebook = Gtk.Notebook()
         self.__notebook.set_show_tabs(False)
         self.__notebook.set_sensitive(False)
         self.__notebook.show()
-        self.pack_start(self.__notebook, True, True, 0)
+        self.__widget.add_child(self.__notebook, mobius.core.ui.box.fill_with_widget)
 
         # tab: contacts view
         self.__contact_view = UserListWidget()
         self.__contact_view.set_list_report_id('skype.contacts')
         self.__contact_view.set_list_report_name('Skype contacts')
         self.__contact_view.set_details_report_id('skype.contact')
-        self.__contact_view.set_details_report_name('skype contact %s')
+        self.__contact_view.set_details_report_name('skype contact')
         self.__contact_view.show()
-        self.__notebook.append_page(self.__contact_view.get_ui_widget(), Gtk.Label.new('contacts'))
+
+        self.__notebook.append_page(self.__contact_view.get_ui_widget(), mobius.core.ui.label('contacts').get_ui_widget())
 
         # tab: voicemail view
         self.__voicemail_listview = pymobius.mediator.call('ui.new-widget', 'tableview')
@@ -602,7 +589,7 @@ class Widget(Gtk.VBox):
         self.__voicemail_listview.set_report_app('%s v%s' % (EXTENSION_NAME, EXTENSION_VERSION))
         self.__voicemail_listview.show()
 
-        self.__notebook.append_page(self.__voicemail_listview.get_ui_widget(), Gtk.Label.new('voicemails'))
+        self.__notebook.append_page(self.__voicemail_listview.get_ui_widget(), mobius.core.ui.label('voicemails').get_ui_widget())
 
         # tab: timeline view
         self.__timeline_view = pymobius.mediator.call('ui.new-widget', 'tableview')
@@ -615,7 +602,7 @@ class Widget(Gtk.VBox):
         self.__timeline_view.set_report_app('%s v%s' % (EXTENSION_NAME, EXTENSION_VERSION))
         self.__timeline_view.show()
 
-        self.__notebook.append_page(self.__timeline_view.get_ui_widget(), Gtk.Label.new('timeline'))
+        self.__notebook.append_page(self.__timeline_view.get_ui_widget(), mobius.core.ui.label('timeline').get_ui_widget())
 
         # tab: record view
         self.__record_view = pymobius.mediator.call('ui.new-widget', 'tableview')
@@ -632,41 +619,47 @@ class Widget(Gtk.VBox):
 
         self.__record_view.set_report_id('skype.records')
         self.__record_view.set_report_name('Skype log records')
-        self.__record_view.set_report_app('%s v%s' % (EXTENSION_NAME, EXTENSION_VERSION))
+        self.__record_view.set_report_app(f'{EXTENSION_NAME} v{EXTENSION_VERSION}')
         self.__record_view.show()
 
-        self.__notebook.append_page(self.__record_view.get_ui_widget(), Gtk.Label.new('records'))
+        self.__notebook.append_page(self.__record_view.get_ui_widget(), mobius.core.ui.label('records').get_ui_widget())
 
         # status bar
         frame = Gtk.Frame()
         frame.set_shadow_type(Gtk.ShadowType.IN)
         frame.show()
-        self.pack_end(frame, False, False, 0)
+        self.__widget.add_child(frame, mobius.core.ui.box.fill_none)
 
-        self.__status_label = Gtk.Label.new()
+        self.__status_label = mobius.core.ui.label()
         self.__status_label.set_selectable(True)
-        self.__status_label.set_xalign(0.0)
-        self.__status_label.set_ellipsize(Pango.EllipsizeMode.MIDDLE)
-        self.__status_label.show()
-        frame.add(self.__status_label)
+        self.__status_label.set_halign(mobius.core.ui.label.align_left)
+        self.__status_label.set_elide_mode(mobius.core.ui.label.elide_middle)
+        self.__status_label.set_visible(True)
+        frame.add(self.__status_label.get_ui_widget())
 
         # data model
         self.__agent = SkypeAgent()
 
+    # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+    # @brief Get widget
+    # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+    def get_widget(self):
+        return self.__widget
+
     # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
     # @brief handle stop event
     # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
     def on_widget_stopped(self):
 
         # show confirmation dialog
-        dialog = mobius.ui.message_dialog(mobius.ui.message_dialog.type_question)
+        dialog = mobius.core.ui.message_dialog(mobius.core.ui.message_dialog.type_question)
         dialog.text = f'Do you want to quit from {EXTENSION_NAME}?'
-        dialog.add_button(mobius.ui.message_dialog.button_yes)
-        dialog.add_button(mobius.ui.message_dialog.button_no)
-        dialog.set_default_response(mobius.ui.message_dialog.button_no)
+        dialog.add_button(mobius.core.ui.message_dialog.button_yes)
+        dialog.add_button(mobius.core.ui.message_dialog.button_no)
+        dialog.set_default_response(mobius.core.ui.message_dialog.button_no)
         rc = dialog.run()
 
-        if rc != mobius.ui.message_dialog.button_yes:
+        if rc != mobius.core.ui.message_dialog.button_yes:
             return True
 
         # close extension
@@ -757,7 +750,7 @@ class Widget(Gtk.VBox):
         fs.add_filter(filefilter)
 
         # set current folder
-        last_folder = mobius.core.get_config('skype-agent.folder') or mobius.core.get_config('general.data-folder')
+        last_folder = mobius.framework.get_config('skype-agent.folder') or mobius.framework.get_config('general.data-folder')
         if last_folder:
             fs.set_current_folder(last_folder)
 
@@ -769,18 +762,18 @@ class Widget(Gtk.VBox):
 
         # if user hit OK add files
         if rc == Gtk.ResponseType.OK:
-            transaction = mobius.core.new_config_transaction()
-            mobius.core.set_config('skype-agent.folder', folder)
-            mobius.core.set_config('general.data-folder', folder)
+            transaction = mobius.framework.new_config_transaction()
+            mobius.framework.set_config('skype-agent.folder', folder)
+            mobius.framework.set_config('general.data-folder', folder)
             transaction.commit()
 
             # interpret log files
             self.__agent = SkypeAgent()
 
             for uri in uri_list:
-                f = mobius.io.new_file_by_url(uri)
+                f = mobius.core.io.new_file_by_url(uri)
                 self.__status_label.set_text(f'Reading file {f.name}...')
-                mobius.ui.flush()
+                mobius.core.ui.flush()
 
                 stream = f.new_reader()
                 self.__agent.add_logfile(stream)
